/**
 * @file cansend.c
 *
 * A simple UDP sender (broadcast) for the CAN-ETH gateway. 
 *
 * @if NOTICE
 *
 * The following source file constitutes example program code and is
 * intended merely to illustrate useful programming techniques.  The user
 * is responsible for applying the code correctly.
 *
 * THIS SOFTWARE IS PROVIDED BY PROCONX AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL PROCONX OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * @endif
 */

 
// Platform header
#include <stdio.h>
#include <stdlib.h>
#ifdef _WIN32
#   include <windows.h>
#else
#   include <unistd.h>
#endif

// Include CAN-ETH API header
#include "canethlib.h"


/**
 * Main function
 *
 * @param argc Command line argument count
 * @param argv Command line argument value string array
 * @return Error code: 0 = OK, else error
 */
int main (int argc, char **argv)
{
    CanHandle hdl;
    CanMsg msg;
    int rc;

    // Check command line arguments
    if (argc != 2)
    {
        fprintf(stderr, "Usage: cansend ipaddr\n");
        return EXIT_FAILURE;
    }

    // Init CAN-ETH library
    rc = canEthInit();
    if (rc != CANETH_SUCCESS)
    {
        fprintf(stderr, "Error initialising CAN-ETH API (%d)!\n", rc);
        return EXIT_FAILURE;
    }

    // Open a CAN channel to a remote CAN-ETH gateway
    hdl = canEthOpen(argv[1]);
    if (hdl < 0)
    {
        fprintf(stderr, "Error opening network connection to CAN-ETH (%d)!\n", hdl);
        canEthShutdown();
        return EXIT_FAILURE;
    }

    //
    // Assemble CAN message
    //
    msg.id = 0x123;
    msg.ext = 0; // Standard identifier
    msg.rtr = 0; // Not a remote frame
    msg.len = 8;
    msg.data[0] = 0x11;
    msg.data[1] = 0x22;
    msg.data[2] = 0x33;
    msg.data[3] = 0x44;
    msg.data[4] = 0x55;
    msg.data[5] = 0x66;
    msg.data[6] = 0x77;
    msg.data[7] = 0x88;

    //
    // Sending CAN message
    //
    rc = canEthSendMsg(hdl, &msg);
    if (rc == CANETH_SUCCESS)
        printf("Message sent sucessfully.\n");
    else
        fprintf(stderr, "Error sending message (%d)!\n", rc);

    // Shutdown the CAN-ETH Ethernet interface
    canEthClose(hdl);
    canEthShutdown();

    return (rc == CANETH_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE);
}
